# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['IntegrationExternalWikiArgs', 'IntegrationExternalWiki']

@pulumi.input_type
class IntegrationExternalWikiArgs:
    def __init__(__self__, *,
                 external_wiki_url: pulumi.Input[str],
                 project: pulumi.Input[str]):
        """
        The set of arguments for constructing a IntegrationExternalWiki resource.
        :param pulumi.Input[str] external_wiki_url: The URL of the external wiki.
        :param pulumi.Input[str] project: ID of the project you want to activate integration on.
        """
        pulumi.set(__self__, "external_wiki_url", external_wiki_url)
        pulumi.set(__self__, "project", project)

    @property
    @pulumi.getter(name="externalWikiUrl")
    def external_wiki_url(self) -> pulumi.Input[str]:
        """
        The URL of the external wiki.
        """
        return pulumi.get(self, "external_wiki_url")

    @external_wiki_url.setter
    def external_wiki_url(self, value: pulumi.Input[str]):
        pulumi.set(self, "external_wiki_url", value)

    @property
    @pulumi.getter
    def project(self) -> pulumi.Input[str]:
        """
        ID of the project you want to activate integration on.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: pulumi.Input[str]):
        pulumi.set(self, "project", value)


@pulumi.input_type
class _IntegrationExternalWikiState:
    def __init__(__self__, *,
                 active: Optional[pulumi.Input[bool]] = None,
                 created_at: Optional[pulumi.Input[str]] = None,
                 external_wiki_url: Optional[pulumi.Input[str]] = None,
                 project: Optional[pulumi.Input[str]] = None,
                 slug: Optional[pulumi.Input[str]] = None,
                 title: Optional[pulumi.Input[str]] = None,
                 updated_at: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering IntegrationExternalWiki resources.
        :param pulumi.Input[bool] active: Whether the integration is active.
        :param pulumi.Input[str] created_at: The ISO8601 date/time that this integration was activated at in UTC.
        :param pulumi.Input[str] external_wiki_url: The URL of the external wiki.
        :param pulumi.Input[str] project: ID of the project you want to activate integration on.
        :param pulumi.Input[str] slug: The name of the integration in lowercase, shortened to 63 bytes, and with everything except 0-9 and a-z replaced with -. No leading / trailing -. Use in URLs, host names and domain names.
        :param pulumi.Input[str] title: Title of the integration.
        :param pulumi.Input[str] updated_at: The ISO8601 date/time that this integration was last updated at in UTC.
        """
        if active is not None:
            pulumi.set(__self__, "active", active)
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if external_wiki_url is not None:
            pulumi.set(__self__, "external_wiki_url", external_wiki_url)
        if project is not None:
            pulumi.set(__self__, "project", project)
        if slug is not None:
            pulumi.set(__self__, "slug", slug)
        if title is not None:
            pulumi.set(__self__, "title", title)
        if updated_at is not None:
            pulumi.set(__self__, "updated_at", updated_at)

    @property
    @pulumi.getter
    def active(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether the integration is active.
        """
        return pulumi.get(self, "active")

    @active.setter
    def active(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "active", value)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[str]]:
        """
        The ISO8601 date/time that this integration was activated at in UTC.
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "created_at", value)

    @property
    @pulumi.getter(name="externalWikiUrl")
    def external_wiki_url(self) -> Optional[pulumi.Input[str]]:
        """
        The URL of the external wiki.
        """
        return pulumi.get(self, "external_wiki_url")

    @external_wiki_url.setter
    def external_wiki_url(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "external_wiki_url", value)

    @property
    @pulumi.getter
    def project(self) -> Optional[pulumi.Input[str]]:
        """
        ID of the project you want to activate integration on.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "project", value)

    @property
    @pulumi.getter
    def slug(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the integration in lowercase, shortened to 63 bytes, and with everything except 0-9 and a-z replaced with -. No leading / trailing -. Use in URLs, host names and domain names.
        """
        return pulumi.get(self, "slug")

    @slug.setter
    def slug(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "slug", value)

    @property
    @pulumi.getter
    def title(self) -> Optional[pulumi.Input[str]]:
        """
        Title of the integration.
        """
        return pulumi.get(self, "title")

    @title.setter
    def title(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "title", value)

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> Optional[pulumi.Input[str]]:
        """
        The ISO8601 date/time that this integration was last updated at in UTC.
        """
        return pulumi.get(self, "updated_at")

    @updated_at.setter
    def updated_at(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "updated_at", value)


class IntegrationExternalWiki(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 external_wiki_url: Optional[pulumi.Input[str]] = None,
                 project: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        The `IntegrationExternalWiki` resource allows to manage the lifecycle of a project integration with External Wiki Service.

        **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/integrations/#external-wiki)

        ## Example Usage

        ```python
        import pulumi
        import pulumi_gitlab as gitlab

        awesome_project = gitlab.Project("awesome_project",
            name="awesome_project",
            description="My awesome project.",
            visibility_level="public")
        wiki = gitlab.IntegrationExternalWiki("wiki",
            project=awesome_project.id,
            external_wiki_url="https://MyAwesomeExternalWikiURL.com")
        ```

        ## Import

        Starting in Terraform v1.5.0 you can use an import block to import `gitlab_integration_external_wiki`. For example:

        terraform

        import {

          to = gitlab_integration_external_wiki.example

          id = "see CLI command below for ID"

        }

        Import using the CLI is supported using the following syntax:

        You can import a gitlab_integration_external_wiki state using the project ID, e.g.

        ```sh
        $ pulumi import gitlab:index/integrationExternalWiki:IntegrationExternalWiki wiki 1
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] external_wiki_url: The URL of the external wiki.
        :param pulumi.Input[str] project: ID of the project you want to activate integration on.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: IntegrationExternalWikiArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        The `IntegrationExternalWiki` resource allows to manage the lifecycle of a project integration with External Wiki Service.

        **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/integrations/#external-wiki)

        ## Example Usage

        ```python
        import pulumi
        import pulumi_gitlab as gitlab

        awesome_project = gitlab.Project("awesome_project",
            name="awesome_project",
            description="My awesome project.",
            visibility_level="public")
        wiki = gitlab.IntegrationExternalWiki("wiki",
            project=awesome_project.id,
            external_wiki_url="https://MyAwesomeExternalWikiURL.com")
        ```

        ## Import

        Starting in Terraform v1.5.0 you can use an import block to import `gitlab_integration_external_wiki`. For example:

        terraform

        import {

          to = gitlab_integration_external_wiki.example

          id = "see CLI command below for ID"

        }

        Import using the CLI is supported using the following syntax:

        You can import a gitlab_integration_external_wiki state using the project ID, e.g.

        ```sh
        $ pulumi import gitlab:index/integrationExternalWiki:IntegrationExternalWiki wiki 1
        ```

        :param str resource_name: The name of the resource.
        :param IntegrationExternalWikiArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(IntegrationExternalWikiArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 external_wiki_url: Optional[pulumi.Input[str]] = None,
                 project: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = IntegrationExternalWikiArgs.__new__(IntegrationExternalWikiArgs)

            if external_wiki_url is None and not opts.urn:
                raise TypeError("Missing required property 'external_wiki_url'")
            __props__.__dict__["external_wiki_url"] = external_wiki_url
            if project is None and not opts.urn:
                raise TypeError("Missing required property 'project'")
            __props__.__dict__["project"] = project
            __props__.__dict__["active"] = None
            __props__.__dict__["created_at"] = None
            __props__.__dict__["slug"] = None
            __props__.__dict__["title"] = None
            __props__.__dict__["updated_at"] = None
        super(IntegrationExternalWiki, __self__).__init__(
            'gitlab:index/integrationExternalWiki:IntegrationExternalWiki',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            active: Optional[pulumi.Input[bool]] = None,
            created_at: Optional[pulumi.Input[str]] = None,
            external_wiki_url: Optional[pulumi.Input[str]] = None,
            project: Optional[pulumi.Input[str]] = None,
            slug: Optional[pulumi.Input[str]] = None,
            title: Optional[pulumi.Input[str]] = None,
            updated_at: Optional[pulumi.Input[str]] = None) -> 'IntegrationExternalWiki':
        """
        Get an existing IntegrationExternalWiki resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] active: Whether the integration is active.
        :param pulumi.Input[str] created_at: The ISO8601 date/time that this integration was activated at in UTC.
        :param pulumi.Input[str] external_wiki_url: The URL of the external wiki.
        :param pulumi.Input[str] project: ID of the project you want to activate integration on.
        :param pulumi.Input[str] slug: The name of the integration in lowercase, shortened to 63 bytes, and with everything except 0-9 and a-z replaced with -. No leading / trailing -. Use in URLs, host names and domain names.
        :param pulumi.Input[str] title: Title of the integration.
        :param pulumi.Input[str] updated_at: The ISO8601 date/time that this integration was last updated at in UTC.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _IntegrationExternalWikiState.__new__(_IntegrationExternalWikiState)

        __props__.__dict__["active"] = active
        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["external_wiki_url"] = external_wiki_url
        __props__.__dict__["project"] = project
        __props__.__dict__["slug"] = slug
        __props__.__dict__["title"] = title
        __props__.__dict__["updated_at"] = updated_at
        return IntegrationExternalWiki(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def active(self) -> pulumi.Output[bool]:
        """
        Whether the integration is active.
        """
        return pulumi.get(self, "active")

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[str]:
        """
        The ISO8601 date/time that this integration was activated at in UTC.
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter(name="externalWikiUrl")
    def external_wiki_url(self) -> pulumi.Output[str]:
        """
        The URL of the external wiki.
        """
        return pulumi.get(self, "external_wiki_url")

    @property
    @pulumi.getter
    def project(self) -> pulumi.Output[str]:
        """
        ID of the project you want to activate integration on.
        """
        return pulumi.get(self, "project")

    @property
    @pulumi.getter
    def slug(self) -> pulumi.Output[str]:
        """
        The name of the integration in lowercase, shortened to 63 bytes, and with everything except 0-9 and a-z replaced with -. No leading / trailing -. Use in URLs, host names and domain names.
        """
        return pulumi.get(self, "slug")

    @property
    @pulumi.getter
    def title(self) -> pulumi.Output[str]:
        """
        Title of the integration.
        """
        return pulumi.get(self, "title")

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> pulumi.Output[str]:
        """
        The ISO8601 date/time that this integration was last updated at in UTC.
        """
        return pulumi.get(self, "updated_at")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['ProjectEnvironmentArgs', 'ProjectEnvironment']

@pulumi.input_type
class ProjectEnvironmentArgs:
    def __init__(__self__, *,
                 project: pulumi.Input[str],
                 auto_stop_setting: Optional[pulumi.Input[str]] = None,
                 cluster_agent_id: Optional[pulumi.Input[int]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 external_url: Optional[pulumi.Input[str]] = None,
                 flux_resource_path: Optional[pulumi.Input[str]] = None,
                 kubernetes_namespace: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 stop_before_destroy: Optional[pulumi.Input[bool]] = None,
                 tier: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a ProjectEnvironment resource.
        :param pulumi.Input[str] project: The ID or full path of the project to environment is created for.
        :param pulumi.Input[str] auto_stop_setting: The auto stop setting for the environment. Allowed values are `always`, `with_action`. If this is set to `with_action` and `stop_before_destroy` is `true`, the environment will be force-stopped.
        :param pulumi.Input[int] cluster_agent_id: The cluster agent to associate with this environment.
        :param pulumi.Input[str] description: The description of the environment.
        :param pulumi.Input[str] external_url: Place to link to for this environment.
        :param pulumi.Input[str] flux_resource_path: The Flux resource path to associate with this environment.
        :param pulumi.Input[str] kubernetes_namespace: The Kubernetes namespace to associate with this environment.
        :param pulumi.Input[str] name: The name of the environment.
        :param pulumi.Input[bool] stop_before_destroy: Determines whether the environment is attempted to be stopped before the environment is deleted. If `auto_stop_setting` is set to `with_action`, this will perform a force stop.
        :param pulumi.Input[str] tier: The tier of the new environment. Valid values are `production`, `staging`, `testing`, `development`, `other`.
        """
        pulumi.set(__self__, "project", project)
        if auto_stop_setting is not None:
            pulumi.set(__self__, "auto_stop_setting", auto_stop_setting)
        if cluster_agent_id is not None:
            pulumi.set(__self__, "cluster_agent_id", cluster_agent_id)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if external_url is not None:
            pulumi.set(__self__, "external_url", external_url)
        if flux_resource_path is not None:
            pulumi.set(__self__, "flux_resource_path", flux_resource_path)
        if kubernetes_namespace is not None:
            pulumi.set(__self__, "kubernetes_namespace", kubernetes_namespace)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if stop_before_destroy is not None:
            pulumi.set(__self__, "stop_before_destroy", stop_before_destroy)
        if tier is not None:
            pulumi.set(__self__, "tier", tier)

    @property
    @pulumi.getter
    def project(self) -> pulumi.Input[str]:
        """
        The ID or full path of the project to environment is created for.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: pulumi.Input[str]):
        pulumi.set(self, "project", value)

    @property
    @pulumi.getter(name="autoStopSetting")
    def auto_stop_setting(self) -> Optional[pulumi.Input[str]]:
        """
        The auto stop setting for the environment. Allowed values are `always`, `with_action`. If this is set to `with_action` and `stop_before_destroy` is `true`, the environment will be force-stopped.
        """
        return pulumi.get(self, "auto_stop_setting")

    @auto_stop_setting.setter
    def auto_stop_setting(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "auto_stop_setting", value)

    @property
    @pulumi.getter(name="clusterAgentId")
    def cluster_agent_id(self) -> Optional[pulumi.Input[int]]:
        """
        The cluster agent to associate with this environment.
        """
        return pulumi.get(self, "cluster_agent_id")

    @cluster_agent_id.setter
    def cluster_agent_id(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "cluster_agent_id", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        The description of the environment.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="externalUrl")
    def external_url(self) -> Optional[pulumi.Input[str]]:
        """
        Place to link to for this environment.
        """
        return pulumi.get(self, "external_url")

    @external_url.setter
    def external_url(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "external_url", value)

    @property
    @pulumi.getter(name="fluxResourcePath")
    def flux_resource_path(self) -> Optional[pulumi.Input[str]]:
        """
        The Flux resource path to associate with this environment.
        """
        return pulumi.get(self, "flux_resource_path")

    @flux_resource_path.setter
    def flux_resource_path(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "flux_resource_path", value)

    @property
    @pulumi.getter(name="kubernetesNamespace")
    def kubernetes_namespace(self) -> Optional[pulumi.Input[str]]:
        """
        The Kubernetes namespace to associate with this environment.
        """
        return pulumi.get(self, "kubernetes_namespace")

    @kubernetes_namespace.setter
    def kubernetes_namespace(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "kubernetes_namespace", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the environment.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="stopBeforeDestroy")
    def stop_before_destroy(self) -> Optional[pulumi.Input[bool]]:
        """
        Determines whether the environment is attempted to be stopped before the environment is deleted. If `auto_stop_setting` is set to `with_action`, this will perform a force stop.
        """
        return pulumi.get(self, "stop_before_destroy")

    @stop_before_destroy.setter
    def stop_before_destroy(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "stop_before_destroy", value)

    @property
    @pulumi.getter
    def tier(self) -> Optional[pulumi.Input[str]]:
        """
        The tier of the new environment. Valid values are `production`, `staging`, `testing`, `development`, `other`.
        """
        return pulumi.get(self, "tier")

    @tier.setter
    def tier(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "tier", value)


@pulumi.input_type
class _ProjectEnvironmentState:
    def __init__(__self__, *,
                 auto_stop_at: Optional[pulumi.Input[str]] = None,
                 auto_stop_setting: Optional[pulumi.Input[str]] = None,
                 cluster_agent_id: Optional[pulumi.Input[int]] = None,
                 created_at: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 external_url: Optional[pulumi.Input[str]] = None,
                 flux_resource_path: Optional[pulumi.Input[str]] = None,
                 kubernetes_namespace: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 project: Optional[pulumi.Input[str]] = None,
                 slug: Optional[pulumi.Input[str]] = None,
                 state: Optional[pulumi.Input[str]] = None,
                 stop_before_destroy: Optional[pulumi.Input[bool]] = None,
                 tier: Optional[pulumi.Input[str]] = None,
                 updated_at: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering ProjectEnvironment resources.
        :param pulumi.Input[str] auto_stop_at: The ISO8601 date/time that this environment will be automatically stopped at in UTC.
        :param pulumi.Input[str] auto_stop_setting: The auto stop setting for the environment. Allowed values are `always`, `with_action`. If this is set to `with_action` and `stop_before_destroy` is `true`, the environment will be force-stopped.
        :param pulumi.Input[int] cluster_agent_id: The cluster agent to associate with this environment.
        :param pulumi.Input[str] created_at: The ISO8601 date/time that this environment was created at in UTC.
        :param pulumi.Input[str] description: The description of the environment.
        :param pulumi.Input[str] external_url: Place to link to for this environment.
        :param pulumi.Input[str] flux_resource_path: The Flux resource path to associate with this environment.
        :param pulumi.Input[str] kubernetes_namespace: The Kubernetes namespace to associate with this environment.
        :param pulumi.Input[str] name: The name of the environment.
        :param pulumi.Input[str] project: The ID or full path of the project to environment is created for.
        :param pulumi.Input[str] slug: The name of the environment in lowercase, shortened to 63 bytes, and with everything except 0-9 and a-z replaced with -. No leading / trailing -. Use in URLs, host names and domain names.
        :param pulumi.Input[str] state: State the environment is in. Valid values are `available`, `stopped`.
        :param pulumi.Input[bool] stop_before_destroy: Determines whether the environment is attempted to be stopped before the environment is deleted. If `auto_stop_setting` is set to `with_action`, this will perform a force stop.
        :param pulumi.Input[str] tier: The tier of the new environment. Valid values are `production`, `staging`, `testing`, `development`, `other`.
        :param pulumi.Input[str] updated_at: The ISO8601 date/time that this environment was last updated at in UTC.
        """
        if auto_stop_at is not None:
            pulumi.set(__self__, "auto_stop_at", auto_stop_at)
        if auto_stop_setting is not None:
            pulumi.set(__self__, "auto_stop_setting", auto_stop_setting)
        if cluster_agent_id is not None:
            pulumi.set(__self__, "cluster_agent_id", cluster_agent_id)
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if external_url is not None:
            pulumi.set(__self__, "external_url", external_url)
        if flux_resource_path is not None:
            pulumi.set(__self__, "flux_resource_path", flux_resource_path)
        if kubernetes_namespace is not None:
            pulumi.set(__self__, "kubernetes_namespace", kubernetes_namespace)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if project is not None:
            pulumi.set(__self__, "project", project)
        if slug is not None:
            pulumi.set(__self__, "slug", slug)
        if state is not None:
            pulumi.set(__self__, "state", state)
        if stop_before_destroy is not None:
            pulumi.set(__self__, "stop_before_destroy", stop_before_destroy)
        if tier is not None:
            pulumi.set(__self__, "tier", tier)
        if updated_at is not None:
            pulumi.set(__self__, "updated_at", updated_at)

    @property
    @pulumi.getter(name="autoStopAt")
    def auto_stop_at(self) -> Optional[pulumi.Input[str]]:
        """
        The ISO8601 date/time that this environment will be automatically stopped at in UTC.
        """
        return pulumi.get(self, "auto_stop_at")

    @auto_stop_at.setter
    def auto_stop_at(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "auto_stop_at", value)

    @property
    @pulumi.getter(name="autoStopSetting")
    def auto_stop_setting(self) -> Optional[pulumi.Input[str]]:
        """
        The auto stop setting for the environment. Allowed values are `always`, `with_action`. If this is set to `with_action` and `stop_before_destroy` is `true`, the environment will be force-stopped.
        """
        return pulumi.get(self, "auto_stop_setting")

    @auto_stop_setting.setter
    def auto_stop_setting(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "auto_stop_setting", value)

    @property
    @pulumi.getter(name="clusterAgentId")
    def cluster_agent_id(self) -> Optional[pulumi.Input[int]]:
        """
        The cluster agent to associate with this environment.
        """
        return pulumi.get(self, "cluster_agent_id")

    @cluster_agent_id.setter
    def cluster_agent_id(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "cluster_agent_id", value)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[str]]:
        """
        The ISO8601 date/time that this environment was created at in UTC.
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "created_at", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        The description of the environment.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="externalUrl")
    def external_url(self) -> Optional[pulumi.Input[str]]:
        """
        Place to link to for this environment.
        """
        return pulumi.get(self, "external_url")

    @external_url.setter
    def external_url(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "external_url", value)

    @property
    @pulumi.getter(name="fluxResourcePath")
    def flux_resource_path(self) -> Optional[pulumi.Input[str]]:
        """
        The Flux resource path to associate with this environment.
        """
        return pulumi.get(self, "flux_resource_path")

    @flux_resource_path.setter
    def flux_resource_path(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "flux_resource_path", value)

    @property
    @pulumi.getter(name="kubernetesNamespace")
    def kubernetes_namespace(self) -> Optional[pulumi.Input[str]]:
        """
        The Kubernetes namespace to associate with this environment.
        """
        return pulumi.get(self, "kubernetes_namespace")

    @kubernetes_namespace.setter
    def kubernetes_namespace(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "kubernetes_namespace", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the environment.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def project(self) -> Optional[pulumi.Input[str]]:
        """
        The ID or full path of the project to environment is created for.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "project", value)

    @property
    @pulumi.getter
    def slug(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the environment in lowercase, shortened to 63 bytes, and with everything except 0-9 and a-z replaced with -. No leading / trailing -. Use in URLs, host names and domain names.
        """
        return pulumi.get(self, "slug")

    @slug.setter
    def slug(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "slug", value)

    @property
    @pulumi.getter
    def state(self) -> Optional[pulumi.Input[str]]:
        """
        State the environment is in. Valid values are `available`, `stopped`.
        """
        return pulumi.get(self, "state")

    @state.setter
    def state(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "state", value)

    @property
    @pulumi.getter(name="stopBeforeDestroy")
    def stop_before_destroy(self) -> Optional[pulumi.Input[bool]]:
        """
        Determines whether the environment is attempted to be stopped before the environment is deleted. If `auto_stop_setting` is set to `with_action`, this will perform a force stop.
        """
        return pulumi.get(self, "stop_before_destroy")

    @stop_before_destroy.setter
    def stop_before_destroy(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "stop_before_destroy", value)

    @property
    @pulumi.getter
    def tier(self) -> Optional[pulumi.Input[str]]:
        """
        The tier of the new environment. Valid values are `production`, `staging`, `testing`, `development`, `other`.
        """
        return pulumi.get(self, "tier")

    @tier.setter
    def tier(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "tier", value)

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> Optional[pulumi.Input[str]]:
        """
        The ISO8601 date/time that this environment was last updated at in UTC.
        """
        return pulumi.get(self, "updated_at")

    @updated_at.setter
    def updated_at(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "updated_at", value)


class ProjectEnvironment(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 auto_stop_setting: Optional[pulumi.Input[str]] = None,
                 cluster_agent_id: Optional[pulumi.Input[int]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 external_url: Optional[pulumi.Input[str]] = None,
                 flux_resource_path: Optional[pulumi.Input[str]] = None,
                 kubernetes_namespace: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 project: Optional[pulumi.Input[str]] = None,
                 stop_before_destroy: Optional[pulumi.Input[bool]] = None,
                 tier: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_gitlab as gitlab

        this = gitlab.Group("this",
            name="example",
            path="example",
            description="An example group")
        this_project = gitlab.Project("this",
            name="example",
            namespace_id=this.id,
            initialize_with_readme=True)
        this_project_environment = gitlab.ProjectEnvironment("this",
            project=this_project.id,
            name="example",
            external_url="www.example.com")
        ```

        ## Import

        Starting in Terraform v1.5.0 you can use an import block to import `gitlab_project_environment`. For example:

        terraform

        import {

          to = gitlab_project_environment.example

          id = "see CLI command below for ID"

        }

        Import using the CLI is supported using the following syntax:

        GitLab project environments can be imported using an id made up of `projectId:environmenId`, e.g.

        ```sh
        $ pulumi import gitlab:index/projectEnvironment:ProjectEnvironment bar 123:321
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] auto_stop_setting: The auto stop setting for the environment. Allowed values are `always`, `with_action`. If this is set to `with_action` and `stop_before_destroy` is `true`, the environment will be force-stopped.
        :param pulumi.Input[int] cluster_agent_id: The cluster agent to associate with this environment.
        :param pulumi.Input[str] description: The description of the environment.
        :param pulumi.Input[str] external_url: Place to link to for this environment.
        :param pulumi.Input[str] flux_resource_path: The Flux resource path to associate with this environment.
        :param pulumi.Input[str] kubernetes_namespace: The Kubernetes namespace to associate with this environment.
        :param pulumi.Input[str] name: The name of the environment.
        :param pulumi.Input[str] project: The ID or full path of the project to environment is created for.
        :param pulumi.Input[bool] stop_before_destroy: Determines whether the environment is attempted to be stopped before the environment is deleted. If `auto_stop_setting` is set to `with_action`, this will perform a force stop.
        :param pulumi.Input[str] tier: The tier of the new environment. Valid values are `production`, `staging`, `testing`, `development`, `other`.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ProjectEnvironmentArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_gitlab as gitlab

        this = gitlab.Group("this",
            name="example",
            path="example",
            description="An example group")
        this_project = gitlab.Project("this",
            name="example",
            namespace_id=this.id,
            initialize_with_readme=True)
        this_project_environment = gitlab.ProjectEnvironment("this",
            project=this_project.id,
            name="example",
            external_url="www.example.com")
        ```

        ## Import

        Starting in Terraform v1.5.0 you can use an import block to import `gitlab_project_environment`. For example:

        terraform

        import {

          to = gitlab_project_environment.example

          id = "see CLI command below for ID"

        }

        Import using the CLI is supported using the following syntax:

        GitLab project environments can be imported using an id made up of `projectId:environmenId`, e.g.

        ```sh
        $ pulumi import gitlab:index/projectEnvironment:ProjectEnvironment bar 123:321
        ```

        :param str resource_name: The name of the resource.
        :param ProjectEnvironmentArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ProjectEnvironmentArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 auto_stop_setting: Optional[pulumi.Input[str]] = None,
                 cluster_agent_id: Optional[pulumi.Input[int]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 external_url: Optional[pulumi.Input[str]] = None,
                 flux_resource_path: Optional[pulumi.Input[str]] = None,
                 kubernetes_namespace: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 project: Optional[pulumi.Input[str]] = None,
                 stop_before_destroy: Optional[pulumi.Input[bool]] = None,
                 tier: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ProjectEnvironmentArgs.__new__(ProjectEnvironmentArgs)

            __props__.__dict__["auto_stop_setting"] = auto_stop_setting
            __props__.__dict__["cluster_agent_id"] = cluster_agent_id
            __props__.__dict__["description"] = description
            __props__.__dict__["external_url"] = external_url
            __props__.__dict__["flux_resource_path"] = flux_resource_path
            __props__.__dict__["kubernetes_namespace"] = kubernetes_namespace
            __props__.__dict__["name"] = name
            if project is None and not opts.urn:
                raise TypeError("Missing required property 'project'")
            __props__.__dict__["project"] = project
            __props__.__dict__["stop_before_destroy"] = stop_before_destroy
            __props__.__dict__["tier"] = tier
            __props__.__dict__["auto_stop_at"] = None
            __props__.__dict__["created_at"] = None
            __props__.__dict__["slug"] = None
            __props__.__dict__["state"] = None
            __props__.__dict__["updated_at"] = None
        super(ProjectEnvironment, __self__).__init__(
            'gitlab:index/projectEnvironment:ProjectEnvironment',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            auto_stop_at: Optional[pulumi.Input[str]] = None,
            auto_stop_setting: Optional[pulumi.Input[str]] = None,
            cluster_agent_id: Optional[pulumi.Input[int]] = None,
            created_at: Optional[pulumi.Input[str]] = None,
            description: Optional[pulumi.Input[str]] = None,
            external_url: Optional[pulumi.Input[str]] = None,
            flux_resource_path: Optional[pulumi.Input[str]] = None,
            kubernetes_namespace: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None,
            project: Optional[pulumi.Input[str]] = None,
            slug: Optional[pulumi.Input[str]] = None,
            state: Optional[pulumi.Input[str]] = None,
            stop_before_destroy: Optional[pulumi.Input[bool]] = None,
            tier: Optional[pulumi.Input[str]] = None,
            updated_at: Optional[pulumi.Input[str]] = None) -> 'ProjectEnvironment':
        """
        Get an existing ProjectEnvironment resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] auto_stop_at: The ISO8601 date/time that this environment will be automatically stopped at in UTC.
        :param pulumi.Input[str] auto_stop_setting: The auto stop setting for the environment. Allowed values are `always`, `with_action`. If this is set to `with_action` and `stop_before_destroy` is `true`, the environment will be force-stopped.
        :param pulumi.Input[int] cluster_agent_id: The cluster agent to associate with this environment.
        :param pulumi.Input[str] created_at: The ISO8601 date/time that this environment was created at in UTC.
        :param pulumi.Input[str] description: The description of the environment.
        :param pulumi.Input[str] external_url: Place to link to for this environment.
        :param pulumi.Input[str] flux_resource_path: The Flux resource path to associate with this environment.
        :param pulumi.Input[str] kubernetes_namespace: The Kubernetes namespace to associate with this environment.
        :param pulumi.Input[str] name: The name of the environment.
        :param pulumi.Input[str] project: The ID or full path of the project to environment is created for.
        :param pulumi.Input[str] slug: The name of the environment in lowercase, shortened to 63 bytes, and with everything except 0-9 and a-z replaced with -. No leading / trailing -. Use in URLs, host names and domain names.
        :param pulumi.Input[str] state: State the environment is in. Valid values are `available`, `stopped`.
        :param pulumi.Input[bool] stop_before_destroy: Determines whether the environment is attempted to be stopped before the environment is deleted. If `auto_stop_setting` is set to `with_action`, this will perform a force stop.
        :param pulumi.Input[str] tier: The tier of the new environment. Valid values are `production`, `staging`, `testing`, `development`, `other`.
        :param pulumi.Input[str] updated_at: The ISO8601 date/time that this environment was last updated at in UTC.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ProjectEnvironmentState.__new__(_ProjectEnvironmentState)

        __props__.__dict__["auto_stop_at"] = auto_stop_at
        __props__.__dict__["auto_stop_setting"] = auto_stop_setting
        __props__.__dict__["cluster_agent_id"] = cluster_agent_id
        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["description"] = description
        __props__.__dict__["external_url"] = external_url
        __props__.__dict__["flux_resource_path"] = flux_resource_path
        __props__.__dict__["kubernetes_namespace"] = kubernetes_namespace
        __props__.__dict__["name"] = name
        __props__.__dict__["project"] = project
        __props__.__dict__["slug"] = slug
        __props__.__dict__["state"] = state
        __props__.__dict__["stop_before_destroy"] = stop_before_destroy
        __props__.__dict__["tier"] = tier
        __props__.__dict__["updated_at"] = updated_at
        return ProjectEnvironment(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="autoStopAt")
    def auto_stop_at(self) -> pulumi.Output[str]:
        """
        The ISO8601 date/time that this environment will be automatically stopped at in UTC.
        """
        return pulumi.get(self, "auto_stop_at")

    @property
    @pulumi.getter(name="autoStopSetting")
    def auto_stop_setting(self) -> pulumi.Output[str]:
        """
        The auto stop setting for the environment. Allowed values are `always`, `with_action`. If this is set to `with_action` and `stop_before_destroy` is `true`, the environment will be force-stopped.
        """
        return pulumi.get(self, "auto_stop_setting")

    @property
    @pulumi.getter(name="clusterAgentId")
    def cluster_agent_id(self) -> pulumi.Output[Optional[int]]:
        """
        The cluster agent to associate with this environment.
        """
        return pulumi.get(self, "cluster_agent_id")

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[str]:
        """
        The ISO8601 date/time that this environment was created at in UTC.
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[str]:
        """
        The description of the environment.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="externalUrl")
    def external_url(self) -> pulumi.Output[Optional[str]]:
        """
        Place to link to for this environment.
        """
        return pulumi.get(self, "external_url")

    @property
    @pulumi.getter(name="fluxResourcePath")
    def flux_resource_path(self) -> pulumi.Output[Optional[str]]:
        """
        The Flux resource path to associate with this environment.
        """
        return pulumi.get(self, "flux_resource_path")

    @property
    @pulumi.getter(name="kubernetesNamespace")
    def kubernetes_namespace(self) -> pulumi.Output[Optional[str]]:
        """
        The Kubernetes namespace to associate with this environment.
        """
        return pulumi.get(self, "kubernetes_namespace")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        The name of the environment.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def project(self) -> pulumi.Output[str]:
        """
        The ID or full path of the project to environment is created for.
        """
        return pulumi.get(self, "project")

    @property
    @pulumi.getter
    def slug(self) -> pulumi.Output[str]:
        """
        The name of the environment in lowercase, shortened to 63 bytes, and with everything except 0-9 and a-z replaced with -. No leading / trailing -. Use in URLs, host names and domain names.
        """
        return pulumi.get(self, "slug")

    @property
    @pulumi.getter
    def state(self) -> pulumi.Output[str]:
        """
        State the environment is in. Valid values are `available`, `stopped`.
        """
        return pulumi.get(self, "state")

    @property
    @pulumi.getter(name="stopBeforeDestroy")
    def stop_before_destroy(self) -> pulumi.Output[Optional[bool]]:
        """
        Determines whether the environment is attempted to be stopped before the environment is deleted. If `auto_stop_setting` is set to `with_action`, this will perform a force stop.
        """
        return pulumi.get(self, "stop_before_destroy")

    @property
    @pulumi.getter
    def tier(self) -> pulumi.Output[str]:
        """
        The tier of the new environment. Valid values are `production`, `staging`, `testing`, `development`, `other`.
        """
        return pulumi.get(self, "tier")

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> pulumi.Output[str]:
        """
        The ISO8601 date/time that this environment was last updated at in UTC.
        """
        return pulumi.get(self, "updated_at")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetProjectEnvironmentsResult',
    'AwaitableGetProjectEnvironmentsResult',
    'get_project_environments',
    'get_project_environments_output',
]

@pulumi.output_type
class GetProjectEnvironmentsResult:
    """
    A collection of values returned by getProjectEnvironments.
    """
    def __init__(__self__, environments=None, id=None, name=None, project=None, search=None, states=None):
        if environments and not isinstance(environments, list):
            raise TypeError("Expected argument 'environments' to be a list")
        pulumi.set(__self__, "environments", environments)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if project and not isinstance(project, str):
            raise TypeError("Expected argument 'project' to be a str")
        pulumi.set(__self__, "project", project)
        if search and not isinstance(search, str):
            raise TypeError("Expected argument 'search' to be a str")
        pulumi.set(__self__, "search", search)
        if states and not isinstance(states, str):
            raise TypeError("Expected argument 'states' to be a str")
        pulumi.set(__self__, "states", states)

    @property
    @pulumi.getter
    def environments(self) -> Sequence['outputs.GetProjectEnvironmentsEnvironmentResult']:
        """
        The list of environments.
        """
        return pulumi.get(self, "environments")

    @property
    @pulumi.getter
    def id(self) -> str:
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> Optional[str]:
        """
        Return the environment with this name. Mutually exclusive with search.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def project(self) -> str:
        """
        The ID or full path of the project.
        """
        return pulumi.get(self, "project")

    @property
    @pulumi.getter
    def search(self) -> Optional[str]:
        """
        Return list of environments matching the search criteria. Mutually exclusive with name. Must be at least 3 characters long.
        """
        return pulumi.get(self, "search")

    @property
    @pulumi.getter
    def states(self) -> Optional[str]:
        """
        List all environments that match the specified state. Valid values are `available`, `stopping`, `stopped`. Returns all environments if not set.
        """
        return pulumi.get(self, "states")


class AwaitableGetProjectEnvironmentsResult(GetProjectEnvironmentsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetProjectEnvironmentsResult(
            environments=self.environments,
            id=self.id,
            name=self.name,
            project=self.project,
            search=self.search,
            states=self.states)


def get_project_environments(name: Optional[str] = None,
                             project: Optional[str] = None,
                             search: Optional[str] = None,
                             states: Optional[str] = None,
                             opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetProjectEnvironmentsResult:
    """
    The `get_project_environments` data source retrieves information about all environments of the given project.

    **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/environments/#list-environments)

    ## Example Usage

    ```python
    import pulumi
    import pulumi_gitlab as gitlab

    this_project = gitlab.Project("this",
        name="example",
        initialize_with_readme=True)
    this = gitlab.get_project_environments_output(project=this_project.path_with_namespace)
    ```


    :param str name: Return the environment with this name. Mutually exclusive with search.
    :param str project: The ID or full path of the project.
    :param str search: Return list of environments matching the search criteria. Mutually exclusive with name. Must be at least 3 characters long.
    :param str states: List all environments that match the specified state. Valid values are `available`, `stopping`, `stopped`. Returns all environments if not set.
    """
    __args__ = dict()
    __args__['name'] = name
    __args__['project'] = project
    __args__['search'] = search
    __args__['states'] = states
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('gitlab:index/getProjectEnvironments:getProjectEnvironments', __args__, opts=opts, typ=GetProjectEnvironmentsResult).value

    return AwaitableGetProjectEnvironmentsResult(
        environments=pulumi.get(__ret__, 'environments'),
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        project=pulumi.get(__ret__, 'project'),
        search=pulumi.get(__ret__, 'search'),
        states=pulumi.get(__ret__, 'states'))
def get_project_environments_output(name: Optional[pulumi.Input[Optional[str]]] = None,
                                    project: Optional[pulumi.Input[str]] = None,
                                    search: Optional[pulumi.Input[Optional[str]]] = None,
                                    states: Optional[pulumi.Input[Optional[str]]] = None,
                                    opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetProjectEnvironmentsResult]:
    """
    The `get_project_environments` data source retrieves information about all environments of the given project.

    **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/environments/#list-environments)

    ## Example Usage

    ```python
    import pulumi
    import pulumi_gitlab as gitlab

    this_project = gitlab.Project("this",
        name="example",
        initialize_with_readme=True)
    this = gitlab.get_project_environments_output(project=this_project.path_with_namespace)
    ```


    :param str name: Return the environment with this name. Mutually exclusive with search.
    :param str project: The ID or full path of the project.
    :param str search: Return list of environments matching the search criteria. Mutually exclusive with name. Must be at least 3 characters long.
    :param str states: List all environments that match the specified state. Valid values are `available`, `stopping`, `stopped`. Returns all environments if not set.
    """
    __args__ = dict()
    __args__['name'] = name
    __args__['project'] = project
    __args__['search'] = search
    __args__['states'] = states
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('gitlab:index/getProjectEnvironments:getProjectEnvironments', __args__, opts=opts, typ=GetProjectEnvironmentsResult)
    return __ret__.apply(lambda __response__: GetProjectEnvironmentsResult(
        environments=pulumi.get(__response__, 'environments'),
        id=pulumi.get(__response__, 'id'),
        name=pulumi.get(__response__, 'name'),
        project=pulumi.get(__response__, 'project'),
        search=pulumi.get(__response__, 'search'),
        states=pulumi.get(__response__, 'states')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['ProjectRunnerEnablementArgs', 'ProjectRunnerEnablement']

@pulumi.input_type
class ProjectRunnerEnablementArgs:
    def __init__(__self__, *,
                 project: pulumi.Input[str],
                 runner_id: pulumi.Input[int]):
        """
        The set of arguments for constructing a ProjectRunnerEnablement resource.
        :param pulumi.Input[str] project: The ID or URL-encoded path of the project owned by the authenticated user.
        :param pulumi.Input[int] runner_id: The ID of a runner to enable for the project.
        """
        pulumi.set(__self__, "project", project)
        pulumi.set(__self__, "runner_id", runner_id)

    @property
    @pulumi.getter
    def project(self) -> pulumi.Input[str]:
        """
        The ID or URL-encoded path of the project owned by the authenticated user.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: pulumi.Input[str]):
        pulumi.set(self, "project", value)

    @property
    @pulumi.getter(name="runnerId")
    def runner_id(self) -> pulumi.Input[int]:
        """
        The ID of a runner to enable for the project.
        """
        return pulumi.get(self, "runner_id")

    @runner_id.setter
    def runner_id(self, value: pulumi.Input[int]):
        pulumi.set(self, "runner_id", value)


@pulumi.input_type
class _ProjectRunnerEnablementState:
    def __init__(__self__, *,
                 project: Optional[pulumi.Input[str]] = None,
                 runner_id: Optional[pulumi.Input[int]] = None):
        """
        Input properties used for looking up and filtering ProjectRunnerEnablement resources.
        :param pulumi.Input[str] project: The ID or URL-encoded path of the project owned by the authenticated user.
        :param pulumi.Input[int] runner_id: The ID of a runner to enable for the project.
        """
        if project is not None:
            pulumi.set(__self__, "project", project)
        if runner_id is not None:
            pulumi.set(__self__, "runner_id", runner_id)

    @property
    @pulumi.getter
    def project(self) -> Optional[pulumi.Input[str]]:
        """
        The ID or URL-encoded path of the project owned by the authenticated user.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "project", value)

    @property
    @pulumi.getter(name="runnerId")
    def runner_id(self) -> Optional[pulumi.Input[int]]:
        """
        The ID of a runner to enable for the project.
        """
        return pulumi.get(self, "runner_id")

    @runner_id.setter
    def runner_id(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "runner_id", value)


class ProjectRunnerEnablement(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 project: Optional[pulumi.Input[str]] = None,
                 runner_id: Optional[pulumi.Input[int]] = None,
                 __props__=None):
        """
        The `ProjectRunnerEnablement` resource allows to enable a runner in a project.

        **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/runners/#enable-a-runner-in-project)

        ## Example Usage

        ```python
        import pulumi
        import pulumi_gitlab as gitlab

        foo = gitlab.ProjectRunnerEnablement("foo",
            project="5",
            runner_id=7)
        ```

        ## Import

        Starting in Terraform v1.5.0 you can use an import block to import `gitlab_project_runner_enablement`. For example:

        terraform

        import {

          to = gitlab_project_runner_enablement.example

          id = "see CLI command below for ID"

        }

        Import using the CLI is supported using the following syntax:

        GitLab project runners can be imported using an id made up of `project:runner_id`, e.g.

        ```sh
        $ pulumi import gitlab:index/projectRunnerEnablement:ProjectRunnerEnablement foo 5:7
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] project: The ID or URL-encoded path of the project owned by the authenticated user.
        :param pulumi.Input[int] runner_id: The ID of a runner to enable for the project.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ProjectRunnerEnablementArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        The `ProjectRunnerEnablement` resource allows to enable a runner in a project.

        **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/runners/#enable-a-runner-in-project)

        ## Example Usage

        ```python
        import pulumi
        import pulumi_gitlab as gitlab

        foo = gitlab.ProjectRunnerEnablement("foo",
            project="5",
            runner_id=7)
        ```

        ## Import

        Starting in Terraform v1.5.0 you can use an import block to import `gitlab_project_runner_enablement`. For example:

        terraform

        import {

          to = gitlab_project_runner_enablement.example

          id = "see CLI command below for ID"

        }

        Import using the CLI is supported using the following syntax:

        GitLab project runners can be imported using an id made up of `project:runner_id`, e.g.

        ```sh
        $ pulumi import gitlab:index/projectRunnerEnablement:ProjectRunnerEnablement foo 5:7
        ```

        :param str resource_name: The name of the resource.
        :param ProjectRunnerEnablementArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ProjectRunnerEnablementArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 project: Optional[pulumi.Input[str]] = None,
                 runner_id: Optional[pulumi.Input[int]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ProjectRunnerEnablementArgs.__new__(ProjectRunnerEnablementArgs)

            if project is None and not opts.urn:
                raise TypeError("Missing required property 'project'")
            __props__.__dict__["project"] = project
            if runner_id is None and not opts.urn:
                raise TypeError("Missing required property 'runner_id'")
            __props__.__dict__["runner_id"] = runner_id
        super(ProjectRunnerEnablement, __self__).__init__(
            'gitlab:index/projectRunnerEnablement:ProjectRunnerEnablement',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            project: Optional[pulumi.Input[str]] = None,
            runner_id: Optional[pulumi.Input[int]] = None) -> 'ProjectRunnerEnablement':
        """
        Get an existing ProjectRunnerEnablement resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] project: The ID or URL-encoded path of the project owned by the authenticated user.
        :param pulumi.Input[int] runner_id: The ID of a runner to enable for the project.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ProjectRunnerEnablementState.__new__(_ProjectRunnerEnablementState)

        __props__.__dict__["project"] = project
        __props__.__dict__["runner_id"] = runner_id
        return ProjectRunnerEnablement(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def project(self) -> pulumi.Output[str]:
        """
        The ID or URL-encoded path of the project owned by the authenticated user.
        """
        return pulumi.get(self, "project")

    @property
    @pulumi.getter(name="runnerId")
    def runner_id(self) -> pulumi.Output[int]:
        """
        The ID of a runner to enable for the project.
        """
        return pulumi.get(self, "runner_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['UserIdentityArgs', 'UserIdentity']

@pulumi.input_type
class UserIdentityArgs:
    def __init__(__self__, *,
                 external_provider: pulumi.Input[str],
                 external_uid: pulumi.Input[str],
                 user_id: pulumi.Input[int]):
        """
        The set of arguments for constructing a UserIdentity resource.
        :param pulumi.Input[str] external_provider: The external provider name.
        :param pulumi.Input[str] external_uid: A specific external authentication provider UID.
        :param pulumi.Input[int] user_id: The GitLab ID of the user.
        """
        pulumi.set(__self__, "external_provider", external_provider)
        pulumi.set(__self__, "external_uid", external_uid)
        pulumi.set(__self__, "user_id", user_id)

    @property
    @pulumi.getter(name="externalProvider")
    def external_provider(self) -> pulumi.Input[str]:
        """
        The external provider name.
        """
        return pulumi.get(self, "external_provider")

    @external_provider.setter
    def external_provider(self, value: pulumi.Input[str]):
        pulumi.set(self, "external_provider", value)

    @property
    @pulumi.getter(name="externalUid")
    def external_uid(self) -> pulumi.Input[str]:
        """
        A specific external authentication provider UID.
        """
        return pulumi.get(self, "external_uid")

    @external_uid.setter
    def external_uid(self, value: pulumi.Input[str]):
        pulumi.set(self, "external_uid", value)

    @property
    @pulumi.getter(name="userId")
    def user_id(self) -> pulumi.Input[int]:
        """
        The GitLab ID of the user.
        """
        return pulumi.get(self, "user_id")

    @user_id.setter
    def user_id(self, value: pulumi.Input[int]):
        pulumi.set(self, "user_id", value)


@pulumi.input_type
class _UserIdentityState:
    def __init__(__self__, *,
                 external_provider: Optional[pulumi.Input[str]] = None,
                 external_uid: Optional[pulumi.Input[str]] = None,
                 user_id: Optional[pulumi.Input[int]] = None):
        """
        Input properties used for looking up and filtering UserIdentity resources.
        :param pulumi.Input[str] external_provider: The external provider name.
        :param pulumi.Input[str] external_uid: A specific external authentication provider UID.
        :param pulumi.Input[int] user_id: The GitLab ID of the user.
        """
        if external_provider is not None:
            pulumi.set(__self__, "external_provider", external_provider)
        if external_uid is not None:
            pulumi.set(__self__, "external_uid", external_uid)
        if user_id is not None:
            pulumi.set(__self__, "user_id", user_id)

    @property
    @pulumi.getter(name="externalProvider")
    def external_provider(self) -> Optional[pulumi.Input[str]]:
        """
        The external provider name.
        """
        return pulumi.get(self, "external_provider")

    @external_provider.setter
    def external_provider(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "external_provider", value)

    @property
    @pulumi.getter(name="externalUid")
    def external_uid(self) -> Optional[pulumi.Input[str]]:
        """
        A specific external authentication provider UID.
        """
        return pulumi.get(self, "external_uid")

    @external_uid.setter
    def external_uid(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "external_uid", value)

    @property
    @pulumi.getter(name="userId")
    def user_id(self) -> Optional[pulumi.Input[int]]:
        """
        The GitLab ID of the user.
        """
        return pulumi.get(self, "user_id")

    @user_id.setter
    def user_id(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "user_id", value)


class UserIdentity(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 external_provider: Optional[pulumi.Input[str]] = None,
                 external_uid: Optional[pulumi.Input[str]] = None,
                 user_id: Optional[pulumi.Input[int]] = None,
                 __props__=None):
        """
        The `UserIdentity` resource is for managing the lifecycle of a user's external identity.

        > the provider needs to be configured with admin-level access for this resource to work.

        **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/users/)

        ## Example Usage

        ```python
        import pulumi
        import pulumi_gitlab as gitlab

        example = gitlab.User("example",
            name="Example Foo",
            username="example",
            email="gitlab@user.create",
            is_admin=True,
            projects_limit=4,
            can_create_group=False,
            is_external=True)
        example_user_identity = gitlab.UserIdentity("example",
            user_id=example.id,
            external_provider="google",
            external_uid="1234567890")
        ```

        ## Import

        Starting in Terraform v1.5.0 you can use an import block to import `gitlab_user_identity`. For example:

        terraform

        import {

          to = gitlab_user_identity.example

          id = "see CLI command below for ID"

        }

        Import using the CLI is supported using the following syntax:

        ```sh
        $ pulumi import gitlab:index/userIdentity:UserIdentity You can import a user identity to terraform state using `<resource> <id>`.
        ```

        The `id` must be a string for the id of the user and identity provider you want to import,

        for example:

        ```sh
        $ pulumi import gitlab:index/userIdentity:UserIdentity example "42:google"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] external_provider: The external provider name.
        :param pulumi.Input[str] external_uid: A specific external authentication provider UID.
        :param pulumi.Input[int] user_id: The GitLab ID of the user.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: UserIdentityArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        The `UserIdentity` resource is for managing the lifecycle of a user's external identity.

        > the provider needs to be configured with admin-level access for this resource to work.

        **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/users/)

        ## Example Usage

        ```python
        import pulumi
        import pulumi_gitlab as gitlab

        example = gitlab.User("example",
            name="Example Foo",
            username="example",
            email="gitlab@user.create",
            is_admin=True,
            projects_limit=4,
            can_create_group=False,
            is_external=True)
        example_user_identity = gitlab.UserIdentity("example",
            user_id=example.id,
            external_provider="google",
            external_uid="1234567890")
        ```

        ## Import

        Starting in Terraform v1.5.0 you can use an import block to import `gitlab_user_identity`. For example:

        terraform

        import {

          to = gitlab_user_identity.example

          id = "see CLI command below for ID"

        }

        Import using the CLI is supported using the following syntax:

        ```sh
        $ pulumi import gitlab:index/userIdentity:UserIdentity You can import a user identity to terraform state using `<resource> <id>`.
        ```

        The `id` must be a string for the id of the user and identity provider you want to import,

        for example:

        ```sh
        $ pulumi import gitlab:index/userIdentity:UserIdentity example "42:google"
        ```

        :param str resource_name: The name of the resource.
        :param UserIdentityArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(UserIdentityArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 external_provider: Optional[pulumi.Input[str]] = None,
                 external_uid: Optional[pulumi.Input[str]] = None,
                 user_id: Optional[pulumi.Input[int]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = UserIdentityArgs.__new__(UserIdentityArgs)

            if external_provider is None and not opts.urn:
                raise TypeError("Missing required property 'external_provider'")
            __props__.__dict__["external_provider"] = external_provider
            if external_uid is None and not opts.urn:
                raise TypeError("Missing required property 'external_uid'")
            __props__.__dict__["external_uid"] = external_uid
            if user_id is None and not opts.urn:
                raise TypeError("Missing required property 'user_id'")
            __props__.__dict__["user_id"] = user_id
        super(UserIdentity, __self__).__init__(
            'gitlab:index/userIdentity:UserIdentity',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            external_provider: Optional[pulumi.Input[str]] = None,
            external_uid: Optional[pulumi.Input[str]] = None,
            user_id: Optional[pulumi.Input[int]] = None) -> 'UserIdentity':
        """
        Get an existing UserIdentity resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] external_provider: The external provider name.
        :param pulumi.Input[str] external_uid: A specific external authentication provider UID.
        :param pulumi.Input[int] user_id: The GitLab ID of the user.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _UserIdentityState.__new__(_UserIdentityState)

        __props__.__dict__["external_provider"] = external_provider
        __props__.__dict__["external_uid"] = external_uid
        __props__.__dict__["user_id"] = user_id
        return UserIdentity(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="externalProvider")
    def external_provider(self) -> pulumi.Output[str]:
        """
        The external provider name.
        """
        return pulumi.get(self, "external_provider")

    @property
    @pulumi.getter(name="externalUid")
    def external_uid(self) -> pulumi.Output[str]:
        """
        A specific external authentication provider UID.
        """
        return pulumi.get(self, "external_uid")

    @property
    @pulumi.getter(name="userId")
    def user_id(self) -> pulumi.Output[int]:
        """
        The GitLab ID of the user.
        """
        return pulumi.get(self, "user_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['PagesDomainArgs', 'PagesDomain']

@pulumi.input_type
class PagesDomainArgs:
    def __init__(__self__, *,
                 domain: pulumi.Input[str],
                 project: pulumi.Input[str],
                 auto_ssl_enabled: Optional[pulumi.Input[bool]] = None,
                 certificate: Optional[pulumi.Input[str]] = None,
                 expired: Optional[pulumi.Input[bool]] = None,
                 key: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a PagesDomain resource.
        :param pulumi.Input[str] domain: The custom domain indicated by the user.
        :param pulumi.Input[str] project: The ID or [URL-encoded path of the project](https://docs.gitlab.com/api/index/#namespaced-path-encoding) owned by the authenticated user.
        :param pulumi.Input[bool] auto_ssl_enabled: Enables [automatic generation](https://docs.gitlab.com/user/project/pages/custom_domains_ssl_tls_certification/lets_encrypt_integration/) of SSL certificates issued by Let’s Encrypt for custom domains. When this is set to "true", certificate can't be provided.
        :param pulumi.Input[str] certificate: The certificate in PEM format with intermediates following in most specific to least specific order.
        :param pulumi.Input[bool] expired: Whether the certificate is expired.
        :param pulumi.Input[str] key: The certificate key in PEM format.
        """
        pulumi.set(__self__, "domain", domain)
        pulumi.set(__self__, "project", project)
        if auto_ssl_enabled is not None:
            pulumi.set(__self__, "auto_ssl_enabled", auto_ssl_enabled)
        if certificate is not None:
            pulumi.set(__self__, "certificate", certificate)
        if expired is not None:
            pulumi.set(__self__, "expired", expired)
        if key is not None:
            pulumi.set(__self__, "key", key)

    @property
    @pulumi.getter
    def domain(self) -> pulumi.Input[str]:
        """
        The custom domain indicated by the user.
        """
        return pulumi.get(self, "domain")

    @domain.setter
    def domain(self, value: pulumi.Input[str]):
        pulumi.set(self, "domain", value)

    @property
    @pulumi.getter
    def project(self) -> pulumi.Input[str]:
        """
        The ID or [URL-encoded path of the project](https://docs.gitlab.com/api/index/#namespaced-path-encoding) owned by the authenticated user.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: pulumi.Input[str]):
        pulumi.set(self, "project", value)

    @property
    @pulumi.getter(name="autoSslEnabled")
    def auto_ssl_enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        Enables [automatic generation](https://docs.gitlab.com/user/project/pages/custom_domains_ssl_tls_certification/lets_encrypt_integration/) of SSL certificates issued by Let’s Encrypt for custom domains. When this is set to "true", certificate can't be provided.
        """
        return pulumi.get(self, "auto_ssl_enabled")

    @auto_ssl_enabled.setter
    def auto_ssl_enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "auto_ssl_enabled", value)

    @property
    @pulumi.getter
    def certificate(self) -> Optional[pulumi.Input[str]]:
        """
        The certificate in PEM format with intermediates following in most specific to least specific order.
        """
        return pulumi.get(self, "certificate")

    @certificate.setter
    def certificate(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "certificate", value)

    @property
    @pulumi.getter
    def expired(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether the certificate is expired.
        """
        return pulumi.get(self, "expired")

    @expired.setter
    def expired(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "expired", value)

    @property
    @pulumi.getter
    def key(self) -> Optional[pulumi.Input[str]]:
        """
        The certificate key in PEM format.
        """
        return pulumi.get(self, "key")

    @key.setter
    def key(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "key", value)


@pulumi.input_type
class _PagesDomainState:
    def __init__(__self__, *,
                 auto_ssl_enabled: Optional[pulumi.Input[bool]] = None,
                 certificate: Optional[pulumi.Input[str]] = None,
                 domain: Optional[pulumi.Input[str]] = None,
                 expired: Optional[pulumi.Input[bool]] = None,
                 key: Optional[pulumi.Input[str]] = None,
                 project: Optional[pulumi.Input[str]] = None,
                 url: Optional[pulumi.Input[str]] = None,
                 verification_code: Optional[pulumi.Input[str]] = None,
                 verified: Optional[pulumi.Input[bool]] = None):
        """
        Input properties used for looking up and filtering PagesDomain resources.
        :param pulumi.Input[bool] auto_ssl_enabled: Enables [automatic generation](https://docs.gitlab.com/user/project/pages/custom_domains_ssl_tls_certification/lets_encrypt_integration/) of SSL certificates issued by Let’s Encrypt for custom domains. When this is set to "true", certificate can't be provided.
        :param pulumi.Input[str] certificate: The certificate in PEM format with intermediates following in most specific to least specific order.
        :param pulumi.Input[str] domain: The custom domain indicated by the user.
        :param pulumi.Input[bool] expired: Whether the certificate is expired.
        :param pulumi.Input[str] key: The certificate key in PEM format.
        :param pulumi.Input[str] project: The ID or [URL-encoded path of the project](https://docs.gitlab.com/api/index/#namespaced-path-encoding) owned by the authenticated user.
        :param pulumi.Input[str] url: The URL for the given domain.
        :param pulumi.Input[str] verification_code: The verification code for the domain.
        :param pulumi.Input[bool] verified: The certificate data.
        """
        if auto_ssl_enabled is not None:
            pulumi.set(__self__, "auto_ssl_enabled", auto_ssl_enabled)
        if certificate is not None:
            pulumi.set(__self__, "certificate", certificate)
        if domain is not None:
            pulumi.set(__self__, "domain", domain)
        if expired is not None:
            pulumi.set(__self__, "expired", expired)
        if key is not None:
            pulumi.set(__self__, "key", key)
        if project is not None:
            pulumi.set(__self__, "project", project)
        if url is not None:
            pulumi.set(__self__, "url", url)
        if verification_code is not None:
            pulumi.set(__self__, "verification_code", verification_code)
        if verified is not None:
            pulumi.set(__self__, "verified", verified)

    @property
    @pulumi.getter(name="autoSslEnabled")
    def auto_ssl_enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        Enables [automatic generation](https://docs.gitlab.com/user/project/pages/custom_domains_ssl_tls_certification/lets_encrypt_integration/) of SSL certificates issued by Let’s Encrypt for custom domains. When this is set to "true", certificate can't be provided.
        """
        return pulumi.get(self, "auto_ssl_enabled")

    @auto_ssl_enabled.setter
    def auto_ssl_enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "auto_ssl_enabled", value)

    @property
    @pulumi.getter
    def certificate(self) -> Optional[pulumi.Input[str]]:
        """
        The certificate in PEM format with intermediates following in most specific to least specific order.
        """
        return pulumi.get(self, "certificate")

    @certificate.setter
    def certificate(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "certificate", value)

    @property
    @pulumi.getter
    def domain(self) -> Optional[pulumi.Input[str]]:
        """
        The custom domain indicated by the user.
        """
        return pulumi.get(self, "domain")

    @domain.setter
    def domain(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "domain", value)

    @property
    @pulumi.getter
    def expired(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether the certificate is expired.
        """
        return pulumi.get(self, "expired")

    @expired.setter
    def expired(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "expired", value)

    @property
    @pulumi.getter
    def key(self) -> Optional[pulumi.Input[str]]:
        """
        The certificate key in PEM format.
        """
        return pulumi.get(self, "key")

    @key.setter
    def key(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "key", value)

    @property
    @pulumi.getter
    def project(self) -> Optional[pulumi.Input[str]]:
        """
        The ID or [URL-encoded path of the project](https://docs.gitlab.com/api/index/#namespaced-path-encoding) owned by the authenticated user.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "project", value)

    @property
    @pulumi.getter
    def url(self) -> Optional[pulumi.Input[str]]:
        """
        The URL for the given domain.
        """
        return pulumi.get(self, "url")

    @url.setter
    def url(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "url", value)

    @property
    @pulumi.getter(name="verificationCode")
    def verification_code(self) -> Optional[pulumi.Input[str]]:
        """
        The verification code for the domain.
        """
        return pulumi.get(self, "verification_code")

    @verification_code.setter
    def verification_code(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "verification_code", value)

    @property
    @pulumi.getter
    def verified(self) -> Optional[pulumi.Input[bool]]:
        """
        The certificate data.
        """
        return pulumi.get(self, "verified")

    @verified.setter
    def verified(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "verified", value)


class PagesDomain(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 auto_ssl_enabled: Optional[pulumi.Input[bool]] = None,
                 certificate: Optional[pulumi.Input[str]] = None,
                 domain: Optional[pulumi.Input[str]] = None,
                 expired: Optional[pulumi.Input[bool]] = None,
                 key: Optional[pulumi.Input[str]] = None,
                 project: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        The `PagesDomain` resource allows connecting custom domains and TLS certificates in GitLab Pages.

        **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/pages_domains/)

        ## Import

        Starting in Terraform v1.5.0 you can use an import block to import `gitlab_pages_domain`. For example:

        terraform

        import {

          to = gitlab_pages_domain.example

          id = "see CLI command below for ID"

        }

        Import using the CLI is supported using the following syntax:

        GitLab pages domain can be imported using an id made up of `projectId:domain` _without_ the http protocol, e.g.

        ```sh
        $ pulumi import gitlab:index/pagesDomain:PagesDomain this 123:example.com
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] auto_ssl_enabled: Enables [automatic generation](https://docs.gitlab.com/user/project/pages/custom_domains_ssl_tls_certification/lets_encrypt_integration/) of SSL certificates issued by Let’s Encrypt for custom domains. When this is set to "true", certificate can't be provided.
        :param pulumi.Input[str] certificate: The certificate in PEM format with intermediates following in most specific to least specific order.
        :param pulumi.Input[str] domain: The custom domain indicated by the user.
        :param pulumi.Input[bool] expired: Whether the certificate is expired.
        :param pulumi.Input[str] key: The certificate key in PEM format.
        :param pulumi.Input[str] project: The ID or [URL-encoded path of the project](https://docs.gitlab.com/api/index/#namespaced-path-encoding) owned by the authenticated user.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: PagesDomainArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        The `PagesDomain` resource allows connecting custom domains and TLS certificates in GitLab Pages.

        **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/pages_domains/)

        ## Import

        Starting in Terraform v1.5.0 you can use an import block to import `gitlab_pages_domain`. For example:

        terraform

        import {

          to = gitlab_pages_domain.example

          id = "see CLI command below for ID"

        }

        Import using the CLI is supported using the following syntax:

        GitLab pages domain can be imported using an id made up of `projectId:domain` _without_ the http protocol, e.g.

        ```sh
        $ pulumi import gitlab:index/pagesDomain:PagesDomain this 123:example.com
        ```

        :param str resource_name: The name of the resource.
        :param PagesDomainArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(PagesDomainArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 auto_ssl_enabled: Optional[pulumi.Input[bool]] = None,
                 certificate: Optional[pulumi.Input[str]] = None,
                 domain: Optional[pulumi.Input[str]] = None,
                 expired: Optional[pulumi.Input[bool]] = None,
                 key: Optional[pulumi.Input[str]] = None,
                 project: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = PagesDomainArgs.__new__(PagesDomainArgs)

            __props__.__dict__["auto_ssl_enabled"] = auto_ssl_enabled
            __props__.__dict__["certificate"] = certificate
            if domain is None and not opts.urn:
                raise TypeError("Missing required property 'domain'")
            __props__.__dict__["domain"] = domain
            __props__.__dict__["expired"] = expired
            __props__.__dict__["key"] = key
            if project is None and not opts.urn:
                raise TypeError("Missing required property 'project'")
            __props__.__dict__["project"] = project
            __props__.__dict__["url"] = None
            __props__.__dict__["verification_code"] = None
            __props__.__dict__["verified"] = None
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["verificationCode"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(PagesDomain, __self__).__init__(
            'gitlab:index/pagesDomain:PagesDomain',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            auto_ssl_enabled: Optional[pulumi.Input[bool]] = None,
            certificate: Optional[pulumi.Input[str]] = None,
            domain: Optional[pulumi.Input[str]] = None,
            expired: Optional[pulumi.Input[bool]] = None,
            key: Optional[pulumi.Input[str]] = None,
            project: Optional[pulumi.Input[str]] = None,
            url: Optional[pulumi.Input[str]] = None,
            verification_code: Optional[pulumi.Input[str]] = None,
            verified: Optional[pulumi.Input[bool]] = None) -> 'PagesDomain':
        """
        Get an existing PagesDomain resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] auto_ssl_enabled: Enables [automatic generation](https://docs.gitlab.com/user/project/pages/custom_domains_ssl_tls_certification/lets_encrypt_integration/) of SSL certificates issued by Let’s Encrypt for custom domains. When this is set to "true", certificate can't be provided.
        :param pulumi.Input[str] certificate: The certificate in PEM format with intermediates following in most specific to least specific order.
        :param pulumi.Input[str] domain: The custom domain indicated by the user.
        :param pulumi.Input[bool] expired: Whether the certificate is expired.
        :param pulumi.Input[str] key: The certificate key in PEM format.
        :param pulumi.Input[str] project: The ID or [URL-encoded path of the project](https://docs.gitlab.com/api/index/#namespaced-path-encoding) owned by the authenticated user.
        :param pulumi.Input[str] url: The URL for the given domain.
        :param pulumi.Input[str] verification_code: The verification code for the domain.
        :param pulumi.Input[bool] verified: The certificate data.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _PagesDomainState.__new__(_PagesDomainState)

        __props__.__dict__["auto_ssl_enabled"] = auto_ssl_enabled
        __props__.__dict__["certificate"] = certificate
        __props__.__dict__["domain"] = domain
        __props__.__dict__["expired"] = expired
        __props__.__dict__["key"] = key
        __props__.__dict__["project"] = project
        __props__.__dict__["url"] = url
        __props__.__dict__["verification_code"] = verification_code
        __props__.__dict__["verified"] = verified
        return PagesDomain(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="autoSslEnabled")
    def auto_ssl_enabled(self) -> pulumi.Output[bool]:
        """
        Enables [automatic generation](https://docs.gitlab.com/user/project/pages/custom_domains_ssl_tls_certification/lets_encrypt_integration/) of SSL certificates issued by Let’s Encrypt for custom domains. When this is set to "true", certificate can't be provided.
        """
        return pulumi.get(self, "auto_ssl_enabled")

    @property
    @pulumi.getter
    def certificate(self) -> pulumi.Output[str]:
        """
        The certificate in PEM format with intermediates following in most specific to least specific order.
        """
        return pulumi.get(self, "certificate")

    @property
    @pulumi.getter
    def domain(self) -> pulumi.Output[str]:
        """
        The custom domain indicated by the user.
        """
        return pulumi.get(self, "domain")

    @property
    @pulumi.getter
    def expired(self) -> pulumi.Output[bool]:
        """
        Whether the certificate is expired.
        """
        return pulumi.get(self, "expired")

    @property
    @pulumi.getter
    def key(self) -> pulumi.Output[Optional[str]]:
        """
        The certificate key in PEM format.
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def project(self) -> pulumi.Output[str]:
        """
        The ID or [URL-encoded path of the project](https://docs.gitlab.com/api/index/#namespaced-path-encoding) owned by the authenticated user.
        """
        return pulumi.get(self, "project")

    @property
    @pulumi.getter
    def url(self) -> pulumi.Output[str]:
        """
        The URL for the given domain.
        """
        return pulumi.get(self, "url")

    @property
    @pulumi.getter(name="verificationCode")
    def verification_code(self) -> pulumi.Output[str]:
        """
        The verification code for the domain.
        """
        return pulumi.get(self, "verification_code")

    @property
    @pulumi.getter
    def verified(self) -> pulumi.Output[bool]:
        """
        The certificate data.
        """
        return pulumi.get(self, "verified")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['ProjectJobTokenScopeArgs', 'ProjectJobTokenScope']

@pulumi.input_type
class ProjectJobTokenScopeArgs:
    def __init__(__self__, *,
                 project: pulumi.Input[str],
                 target_group_id: Optional[pulumi.Input[int]] = None,
                 target_project_id: Optional[pulumi.Input[int]] = None):
        """
        The set of arguments for constructing a ProjectJobTokenScope resource.
        :param pulumi.Input[str] project: The ID or full path of the project.
        :param pulumi.Input[int] target_group_id: The ID of the group that is in the CI/CD job token inbound allowlist.
        :param pulumi.Input[int] target_project_id: The ID of the project that is in the CI/CD job token inbound allowlist.
        """
        pulumi.set(__self__, "project", project)
        if target_group_id is not None:
            pulumi.set(__self__, "target_group_id", target_group_id)
        if target_project_id is not None:
            pulumi.set(__self__, "target_project_id", target_project_id)

    @property
    @pulumi.getter
    def project(self) -> pulumi.Input[str]:
        """
        The ID or full path of the project.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: pulumi.Input[str]):
        pulumi.set(self, "project", value)

    @property
    @pulumi.getter(name="targetGroupId")
    def target_group_id(self) -> Optional[pulumi.Input[int]]:
        """
        The ID of the group that is in the CI/CD job token inbound allowlist.
        """
        return pulumi.get(self, "target_group_id")

    @target_group_id.setter
    def target_group_id(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "target_group_id", value)

    @property
    @pulumi.getter(name="targetProjectId")
    def target_project_id(self) -> Optional[pulumi.Input[int]]:
        """
        The ID of the project that is in the CI/CD job token inbound allowlist.
        """
        return pulumi.get(self, "target_project_id")

    @target_project_id.setter
    def target_project_id(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "target_project_id", value)


@pulumi.input_type
class _ProjectJobTokenScopeState:
    def __init__(__self__, *,
                 project: Optional[pulumi.Input[str]] = None,
                 target_group_id: Optional[pulumi.Input[int]] = None,
                 target_project_id: Optional[pulumi.Input[int]] = None):
        """
        Input properties used for looking up and filtering ProjectJobTokenScope resources.
        :param pulumi.Input[str] project: The ID or full path of the project.
        :param pulumi.Input[int] target_group_id: The ID of the group that is in the CI/CD job token inbound allowlist.
        :param pulumi.Input[int] target_project_id: The ID of the project that is in the CI/CD job token inbound allowlist.
        """
        if project is not None:
            pulumi.set(__self__, "project", project)
        if target_group_id is not None:
            pulumi.set(__self__, "target_group_id", target_group_id)
        if target_project_id is not None:
            pulumi.set(__self__, "target_project_id", target_project_id)

    @property
    @pulumi.getter
    def project(self) -> Optional[pulumi.Input[str]]:
        """
        The ID or full path of the project.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "project", value)

    @property
    @pulumi.getter(name="targetGroupId")
    def target_group_id(self) -> Optional[pulumi.Input[int]]:
        """
        The ID of the group that is in the CI/CD job token inbound allowlist.
        """
        return pulumi.get(self, "target_group_id")

    @target_group_id.setter
    def target_group_id(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "target_group_id", value)

    @property
    @pulumi.getter(name="targetProjectId")
    def target_project_id(self) -> Optional[pulumi.Input[int]]:
        """
        The ID of the project that is in the CI/CD job token inbound allowlist.
        """
        return pulumi.get(self, "target_project_id")

    @target_project_id.setter
    def target_project_id(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "target_project_id", value)


class ProjectJobTokenScope(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 project: Optional[pulumi.Input[str]] = None,
                 target_group_id: Optional[pulumi.Input[int]] = None,
                 target_project_id: Optional[pulumi.Input[int]] = None,
                 __props__=None):
        """
        The `ProjectJobTokenScope` resource allows to manage the CI/CD Job Token scope in a project.
        Any projects added to the CI/CD Job Token scope outside of TF will be untouched by the resource.

        > Conflicts with the use of `ProjectJobTokenScopes` when used on the same project. Use one or the other to ensure the desired state.

        **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/project_job_token_scopes/)

        ## Import

        Starting in Terraform v1.5.0 you can use an import block to import `gitlab_project_job_token_scope`. For example:

        terraform

        import {

          to = gitlab_project_job_token_scope.example

          id = "see CLI command below for ID"

        }

        Import using the CLI is supported using the following syntax:

        GitLab project job token scopes can be imported using an id made up of `projectId:targetProjectId`, e.g.

        ```sh
        $ pulumi import gitlab:index/projectJobTokenScope:ProjectJobTokenScope bar 123:321
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] project: The ID or full path of the project.
        :param pulumi.Input[int] target_group_id: The ID of the group that is in the CI/CD job token inbound allowlist.
        :param pulumi.Input[int] target_project_id: The ID of the project that is in the CI/CD job token inbound allowlist.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ProjectJobTokenScopeArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        The `ProjectJobTokenScope` resource allows to manage the CI/CD Job Token scope in a project.
        Any projects added to the CI/CD Job Token scope outside of TF will be untouched by the resource.

        > Conflicts with the use of `ProjectJobTokenScopes` when used on the same project. Use one or the other to ensure the desired state.

        **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/project_job_token_scopes/)

        ## Import

        Starting in Terraform v1.5.0 you can use an import block to import `gitlab_project_job_token_scope`. For example:

        terraform

        import {

          to = gitlab_project_job_token_scope.example

          id = "see CLI command below for ID"

        }

        Import using the CLI is supported using the following syntax:

        GitLab project job token scopes can be imported using an id made up of `projectId:targetProjectId`, e.g.

        ```sh
        $ pulumi import gitlab:index/projectJobTokenScope:ProjectJobTokenScope bar 123:321
        ```

        :param str resource_name: The name of the resource.
        :param ProjectJobTokenScopeArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ProjectJobTokenScopeArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 project: Optional[pulumi.Input[str]] = None,
                 target_group_id: Optional[pulumi.Input[int]] = None,
                 target_project_id: Optional[pulumi.Input[int]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ProjectJobTokenScopeArgs.__new__(ProjectJobTokenScopeArgs)

            if project is None and not opts.urn:
                raise TypeError("Missing required property 'project'")
            __props__.__dict__["project"] = project
            __props__.__dict__["target_group_id"] = target_group_id
            __props__.__dict__["target_project_id"] = target_project_id
        super(ProjectJobTokenScope, __self__).__init__(
            'gitlab:index/projectJobTokenScope:ProjectJobTokenScope',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            project: Optional[pulumi.Input[str]] = None,
            target_group_id: Optional[pulumi.Input[int]] = None,
            target_project_id: Optional[pulumi.Input[int]] = None) -> 'ProjectJobTokenScope':
        """
        Get an existing ProjectJobTokenScope resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] project: The ID or full path of the project.
        :param pulumi.Input[int] target_group_id: The ID of the group that is in the CI/CD job token inbound allowlist.
        :param pulumi.Input[int] target_project_id: The ID of the project that is in the CI/CD job token inbound allowlist.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ProjectJobTokenScopeState.__new__(_ProjectJobTokenScopeState)

        __props__.__dict__["project"] = project
        __props__.__dict__["target_group_id"] = target_group_id
        __props__.__dict__["target_project_id"] = target_project_id
        return ProjectJobTokenScope(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def project(self) -> pulumi.Output[str]:
        """
        The ID or full path of the project.
        """
        return pulumi.get(self, "project")

    @property
    @pulumi.getter(name="targetGroupId")
    def target_group_id(self) -> pulumi.Output[Optional[int]]:
        """
        The ID of the group that is in the CI/CD job token inbound allowlist.
        """
        return pulumi.get(self, "target_group_id")

    @property
    @pulumi.getter(name="targetProjectId")
    def target_project_id(self) -> pulumi.Output[Optional[int]]:
        """
        The ID of the project that is in the CI/CD job token inbound allowlist.
        """
        return pulumi.get(self, "target_project_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetProjectMembershipResult',
    'AwaitableGetProjectMembershipResult',
    'get_project_membership',
    'get_project_membership_output',
]

@pulumi.output_type
class GetProjectMembershipResult:
    """
    A collection of values returned by getProjectMembership.
    """
    def __init__(__self__, full_path=None, id=None, inherited=None, members=None, project_id=None, query=None, user_ids=None):
        if full_path and not isinstance(full_path, str):
            raise TypeError("Expected argument 'full_path' to be a str")
        pulumi.set(__self__, "full_path", full_path)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if inherited and not isinstance(inherited, bool):
            raise TypeError("Expected argument 'inherited' to be a bool")
        pulumi.set(__self__, "inherited", inherited)
        if members and not isinstance(members, list):
            raise TypeError("Expected argument 'members' to be a list")
        pulumi.set(__self__, "members", members)
        if project_id and not isinstance(project_id, int):
            raise TypeError("Expected argument 'project_id' to be a int")
        pulumi.set(__self__, "project_id", project_id)
        if query and not isinstance(query, str):
            raise TypeError("Expected argument 'query' to be a str")
        pulumi.set(__self__, "query", query)
        if user_ids and not isinstance(user_ids, list):
            raise TypeError("Expected argument 'user_ids' to be a list")
        pulumi.set(__self__, "user_ids", user_ids)

    @property
    @pulumi.getter(name="fullPath")
    def full_path(self) -> str:
        """
        The full path of the project.
        """
        return pulumi.get(self, "full_path")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def inherited(self) -> Optional[bool]:
        """
        Return all project members including members through ancestor groups
        """
        return pulumi.get(self, "inherited")

    @property
    @pulumi.getter
    def members(self) -> Sequence['outputs.GetProjectMembershipMemberResult']:
        """
        The list of project members.
        """
        return pulumi.get(self, "members")

    @property
    @pulumi.getter(name="projectId")
    def project_id(self) -> int:
        """
        The ID of the project.
        """
        return pulumi.get(self, "project_id")

    @property
    @pulumi.getter
    def query(self) -> Optional[str]:
        """
        A query string to search for members
        """
        return pulumi.get(self, "query")

    @property
    @pulumi.getter(name="userIds")
    def user_ids(self) -> Optional[Sequence[int]]:
        """
        List of user ids to filter members by
        """
        return pulumi.get(self, "user_ids")


class AwaitableGetProjectMembershipResult(GetProjectMembershipResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetProjectMembershipResult(
            full_path=self.full_path,
            id=self.id,
            inherited=self.inherited,
            members=self.members,
            project_id=self.project_id,
            query=self.query,
            user_ids=self.user_ids)


def get_project_membership(full_path: Optional[str] = None,
                           inherited: Optional[bool] = None,
                           project_id: Optional[int] = None,
                           query: Optional[str] = None,
                           user_ids: Optional[Sequence[int]] = None,
                           opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetProjectMembershipResult:
    """
    The `ProjectMembership` data source allows to list and filter all members of a project specified by either its id or full path.

    > **Note** exactly one of project_id or full_path must be provided.

    **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/members/#list-all-members-of-a-group-or-project)


    :param str full_path: The full path of the project.
    :param bool inherited: Return all project members including members through ancestor groups
    :param int project_id: The ID of the project.
    :param str query: A query string to search for members
    :param Sequence[int] user_ids: List of user ids to filter members by
    """
    __args__ = dict()
    __args__['fullPath'] = full_path
    __args__['inherited'] = inherited
    __args__['projectId'] = project_id
    __args__['query'] = query
    __args__['userIds'] = user_ids
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('gitlab:index/getProjectMembership:getProjectMembership', __args__, opts=opts, typ=GetProjectMembershipResult).value

    return AwaitableGetProjectMembershipResult(
        full_path=pulumi.get(__ret__, 'full_path'),
        id=pulumi.get(__ret__, 'id'),
        inherited=pulumi.get(__ret__, 'inherited'),
        members=pulumi.get(__ret__, 'members'),
        project_id=pulumi.get(__ret__, 'project_id'),
        query=pulumi.get(__ret__, 'query'),
        user_ids=pulumi.get(__ret__, 'user_ids'))
def get_project_membership_output(full_path: Optional[pulumi.Input[Optional[str]]] = None,
                                  inherited: Optional[pulumi.Input[Optional[bool]]] = None,
                                  project_id: Optional[pulumi.Input[Optional[int]]] = None,
                                  query: Optional[pulumi.Input[Optional[str]]] = None,
                                  user_ids: Optional[pulumi.Input[Optional[Sequence[int]]]] = None,
                                  opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetProjectMembershipResult]:
    """
    The `ProjectMembership` data source allows to list and filter all members of a project specified by either its id or full path.

    > **Note** exactly one of project_id or full_path must be provided.

    **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/members/#list-all-members-of-a-group-or-project)


    :param str full_path: The full path of the project.
    :param bool inherited: Return all project members including members through ancestor groups
    :param int project_id: The ID of the project.
    :param str query: A query string to search for members
    :param Sequence[int] user_ids: List of user ids to filter members by
    """
    __args__ = dict()
    __args__['fullPath'] = full_path
    __args__['inherited'] = inherited
    __args__['projectId'] = project_id
    __args__['query'] = query
    __args__['userIds'] = user_ids
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('gitlab:index/getProjectMembership:getProjectMembership', __args__, opts=opts, typ=GetProjectMembershipResult)
    return __ret__.apply(lambda __response__: GetProjectMembershipResult(
        full_path=pulumi.get(__response__, 'full_path'),
        id=pulumi.get(__response__, 'id'),
        inherited=pulumi.get(__response__, 'inherited'),
        members=pulumi.get(__response__, 'members'),
        project_id=pulumi.get(__response__, 'project_id'),
        query=pulumi.get(__response__, 'query'),
        user_ids=pulumi.get(__response__, 'user_ids')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['ProjectFreezePeriodArgs', 'ProjectFreezePeriod']

@pulumi.input_type
class ProjectFreezePeriodArgs:
    def __init__(__self__, *,
                 freeze_end: pulumi.Input[str],
                 freeze_start: pulumi.Input[str],
                 project: pulumi.Input[str],
                 cron_timezone: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a ProjectFreezePeriod resource.
        :param pulumi.Input[str] freeze_end: End of the Freeze Period in cron format (e.g. `0 2 * * *`).
        :param pulumi.Input[str] freeze_start: Start of the Freeze Period in cron format (e.g. `0 1 * * *`).
        :param pulumi.Input[str] project: The ID or URL-encoded path of the project to add the schedule to.
        :param pulumi.Input[str] cron_timezone: The timezone.
        """
        pulumi.set(__self__, "freeze_end", freeze_end)
        pulumi.set(__self__, "freeze_start", freeze_start)
        pulumi.set(__self__, "project", project)
        if cron_timezone is not None:
            pulumi.set(__self__, "cron_timezone", cron_timezone)

    @property
    @pulumi.getter(name="freezeEnd")
    def freeze_end(self) -> pulumi.Input[str]:
        """
        End of the Freeze Period in cron format (e.g. `0 2 * * *`).
        """
        return pulumi.get(self, "freeze_end")

    @freeze_end.setter
    def freeze_end(self, value: pulumi.Input[str]):
        pulumi.set(self, "freeze_end", value)

    @property
    @pulumi.getter(name="freezeStart")
    def freeze_start(self) -> pulumi.Input[str]:
        """
        Start of the Freeze Period in cron format (e.g. `0 1 * * *`).
        """
        return pulumi.get(self, "freeze_start")

    @freeze_start.setter
    def freeze_start(self, value: pulumi.Input[str]):
        pulumi.set(self, "freeze_start", value)

    @property
    @pulumi.getter
    def project(self) -> pulumi.Input[str]:
        """
        The ID or URL-encoded path of the project to add the schedule to.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: pulumi.Input[str]):
        pulumi.set(self, "project", value)

    @property
    @pulumi.getter(name="cronTimezone")
    def cron_timezone(self) -> Optional[pulumi.Input[str]]:
        """
        The timezone.
        """
        return pulumi.get(self, "cron_timezone")

    @cron_timezone.setter
    def cron_timezone(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cron_timezone", value)


@pulumi.input_type
class _ProjectFreezePeriodState:
    def __init__(__self__, *,
                 cron_timezone: Optional[pulumi.Input[str]] = None,
                 freeze_end: Optional[pulumi.Input[str]] = None,
                 freeze_start: Optional[pulumi.Input[str]] = None,
                 project: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering ProjectFreezePeriod resources.
        :param pulumi.Input[str] cron_timezone: The timezone.
        :param pulumi.Input[str] freeze_end: End of the Freeze Period in cron format (e.g. `0 2 * * *`).
        :param pulumi.Input[str] freeze_start: Start of the Freeze Period in cron format (e.g. `0 1 * * *`).
        :param pulumi.Input[str] project: The ID or URL-encoded path of the project to add the schedule to.
        """
        if cron_timezone is not None:
            pulumi.set(__self__, "cron_timezone", cron_timezone)
        if freeze_end is not None:
            pulumi.set(__self__, "freeze_end", freeze_end)
        if freeze_start is not None:
            pulumi.set(__self__, "freeze_start", freeze_start)
        if project is not None:
            pulumi.set(__self__, "project", project)

    @property
    @pulumi.getter(name="cronTimezone")
    def cron_timezone(self) -> Optional[pulumi.Input[str]]:
        """
        The timezone.
        """
        return pulumi.get(self, "cron_timezone")

    @cron_timezone.setter
    def cron_timezone(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cron_timezone", value)

    @property
    @pulumi.getter(name="freezeEnd")
    def freeze_end(self) -> Optional[pulumi.Input[str]]:
        """
        End of the Freeze Period in cron format (e.g. `0 2 * * *`).
        """
        return pulumi.get(self, "freeze_end")

    @freeze_end.setter
    def freeze_end(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "freeze_end", value)

    @property
    @pulumi.getter(name="freezeStart")
    def freeze_start(self) -> Optional[pulumi.Input[str]]:
        """
        Start of the Freeze Period in cron format (e.g. `0 1 * * *`).
        """
        return pulumi.get(self, "freeze_start")

    @freeze_start.setter
    def freeze_start(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "freeze_start", value)

    @property
    @pulumi.getter
    def project(self) -> Optional[pulumi.Input[str]]:
        """
        The ID or URL-encoded path of the project to add the schedule to.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "project", value)


class ProjectFreezePeriod(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cron_timezone: Optional[pulumi.Input[str]] = None,
                 freeze_end: Optional[pulumi.Input[str]] = None,
                 freeze_start: Optional[pulumi.Input[str]] = None,
                 project: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        The `ProjectFreezePeriod` resource allows to manage the lifecycle of a freeze period for a project.

        **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/freeze_periods/)

        ## Example Usage

        ```python
        import pulumi
        import pulumi_gitlab as gitlab

        schedule = gitlab.ProjectFreezePeriod("schedule",
            project=foo["id"],
            freeze_start="0 23 * * 5",
            freeze_end="0 7 * * 1",
            cron_timezone="UTC")
        ```

        ## Import

        Starting in Terraform v1.5.0 you can use an import block to import `gitlab_project_freeze_period`. For example:

        terraform

        import {

          to = gitlab_project_freeze_period.example

          id = "see CLI command below for ID"

        }

        Import using the CLI is supported using the following syntax:

        GitLab project freeze periods can be imported using an id made up of `project_id:freeze_period_id`, e.g.

        ```sh
        $ pulumi import gitlab:index/projectFreezePeriod:ProjectFreezePeriod schedule "12345:1337"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] cron_timezone: The timezone.
        :param pulumi.Input[str] freeze_end: End of the Freeze Period in cron format (e.g. `0 2 * * *`).
        :param pulumi.Input[str] freeze_start: Start of the Freeze Period in cron format (e.g. `0 1 * * *`).
        :param pulumi.Input[str] project: The ID or URL-encoded path of the project to add the schedule to.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ProjectFreezePeriodArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        The `ProjectFreezePeriod` resource allows to manage the lifecycle of a freeze period for a project.

        **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/freeze_periods/)

        ## Example Usage

        ```python
        import pulumi
        import pulumi_gitlab as gitlab

        schedule = gitlab.ProjectFreezePeriod("schedule",
            project=foo["id"],
            freeze_start="0 23 * * 5",
            freeze_end="0 7 * * 1",
            cron_timezone="UTC")
        ```

        ## Import

        Starting in Terraform v1.5.0 you can use an import block to import `gitlab_project_freeze_period`. For example:

        terraform

        import {

          to = gitlab_project_freeze_period.example

          id = "see CLI command below for ID"

        }

        Import using the CLI is supported using the following syntax:

        GitLab project freeze periods can be imported using an id made up of `project_id:freeze_period_id`, e.g.

        ```sh
        $ pulumi import gitlab:index/projectFreezePeriod:ProjectFreezePeriod schedule "12345:1337"
        ```

        :param str resource_name: The name of the resource.
        :param ProjectFreezePeriodArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ProjectFreezePeriodArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cron_timezone: Optional[pulumi.Input[str]] = None,
                 freeze_end: Optional[pulumi.Input[str]] = None,
                 freeze_start: Optional[pulumi.Input[str]] = None,
                 project: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ProjectFreezePeriodArgs.__new__(ProjectFreezePeriodArgs)

            __props__.__dict__["cron_timezone"] = cron_timezone
            if freeze_end is None and not opts.urn:
                raise TypeError("Missing required property 'freeze_end'")
            __props__.__dict__["freeze_end"] = freeze_end
            if freeze_start is None and not opts.urn:
                raise TypeError("Missing required property 'freeze_start'")
            __props__.__dict__["freeze_start"] = freeze_start
            if project is None and not opts.urn:
                raise TypeError("Missing required property 'project'")
            __props__.__dict__["project"] = project
        super(ProjectFreezePeriod, __self__).__init__(
            'gitlab:index/projectFreezePeriod:ProjectFreezePeriod',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            cron_timezone: Optional[pulumi.Input[str]] = None,
            freeze_end: Optional[pulumi.Input[str]] = None,
            freeze_start: Optional[pulumi.Input[str]] = None,
            project: Optional[pulumi.Input[str]] = None) -> 'ProjectFreezePeriod':
        """
        Get an existing ProjectFreezePeriod resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] cron_timezone: The timezone.
        :param pulumi.Input[str] freeze_end: End of the Freeze Period in cron format (e.g. `0 2 * * *`).
        :param pulumi.Input[str] freeze_start: Start of the Freeze Period in cron format (e.g. `0 1 * * *`).
        :param pulumi.Input[str] project: The ID or URL-encoded path of the project to add the schedule to.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ProjectFreezePeriodState.__new__(_ProjectFreezePeriodState)

        __props__.__dict__["cron_timezone"] = cron_timezone
        __props__.__dict__["freeze_end"] = freeze_end
        __props__.__dict__["freeze_start"] = freeze_start
        __props__.__dict__["project"] = project
        return ProjectFreezePeriod(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="cronTimezone")
    def cron_timezone(self) -> pulumi.Output[Optional[str]]:
        """
        The timezone.
        """
        return pulumi.get(self, "cron_timezone")

    @property
    @pulumi.getter(name="freezeEnd")
    def freeze_end(self) -> pulumi.Output[str]:
        """
        End of the Freeze Period in cron format (e.g. `0 2 * * *`).
        """
        return pulumi.get(self, "freeze_end")

    @property
    @pulumi.getter(name="freezeStart")
    def freeze_start(self) -> pulumi.Output[str]:
        """
        Start of the Freeze Period in cron format (e.g. `0 1 * * *`).
        """
        return pulumi.get(self, "freeze_start")

    @property
    @pulumi.getter
    def project(self) -> pulumi.Output[str]:
        """
        The ID or URL-encoded path of the project to add the schedule to.
        """
        return pulumi.get(self, "project")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['ProjectTargetBranchRuleArgs', 'ProjectTargetBranchRule']

@pulumi.input_type
class ProjectTargetBranchRuleArgs:
    def __init__(__self__, *,
                 project: pulumi.Input[str],
                 source_branch_pattern: pulumi.Input[str],
                 target_branch_name: pulumi.Input[str]):
        """
        The set of arguments for constructing a ProjectTargetBranchRule resource.
        :param pulumi.Input[str] project: The ID or URL-encoded path of the project.
        :param pulumi.Input[str] source_branch_pattern: A pattern matching the branch name for which the merge request should have a default target branch configured.
        :param pulumi.Input[str] target_branch_name: The name of the branch to which the merge request should be addressed.
        """
        pulumi.set(__self__, "project", project)
        pulumi.set(__self__, "source_branch_pattern", source_branch_pattern)
        pulumi.set(__self__, "target_branch_name", target_branch_name)

    @property
    @pulumi.getter
    def project(self) -> pulumi.Input[str]:
        """
        The ID or URL-encoded path of the project.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: pulumi.Input[str]):
        pulumi.set(self, "project", value)

    @property
    @pulumi.getter(name="sourceBranchPattern")
    def source_branch_pattern(self) -> pulumi.Input[str]:
        """
        A pattern matching the branch name for which the merge request should have a default target branch configured.
        """
        return pulumi.get(self, "source_branch_pattern")

    @source_branch_pattern.setter
    def source_branch_pattern(self, value: pulumi.Input[str]):
        pulumi.set(self, "source_branch_pattern", value)

    @property
    @pulumi.getter(name="targetBranchName")
    def target_branch_name(self) -> pulumi.Input[str]:
        """
        The name of the branch to which the merge request should be addressed.
        """
        return pulumi.get(self, "target_branch_name")

    @target_branch_name.setter
    def target_branch_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "target_branch_name", value)


@pulumi.input_type
class _ProjectTargetBranchRuleState:
    def __init__(__self__, *,
                 project: Optional[pulumi.Input[str]] = None,
                 source_branch_pattern: Optional[pulumi.Input[str]] = None,
                 target_branch_name: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering ProjectTargetBranchRule resources.
        :param pulumi.Input[str] project: The ID or URL-encoded path of the project.
        :param pulumi.Input[str] source_branch_pattern: A pattern matching the branch name for which the merge request should have a default target branch configured.
        :param pulumi.Input[str] target_branch_name: The name of the branch to which the merge request should be addressed.
        """
        if project is not None:
            pulumi.set(__self__, "project", project)
        if source_branch_pattern is not None:
            pulumi.set(__self__, "source_branch_pattern", source_branch_pattern)
        if target_branch_name is not None:
            pulumi.set(__self__, "target_branch_name", target_branch_name)

    @property
    @pulumi.getter
    def project(self) -> Optional[pulumi.Input[str]]:
        """
        The ID or URL-encoded path of the project.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "project", value)

    @property
    @pulumi.getter(name="sourceBranchPattern")
    def source_branch_pattern(self) -> Optional[pulumi.Input[str]]:
        """
        A pattern matching the branch name for which the merge request should have a default target branch configured.
        """
        return pulumi.get(self, "source_branch_pattern")

    @source_branch_pattern.setter
    def source_branch_pattern(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "source_branch_pattern", value)

    @property
    @pulumi.getter(name="targetBranchName")
    def target_branch_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the branch to which the merge request should be addressed.
        """
        return pulumi.get(self, "target_branch_name")

    @target_branch_name.setter
    def target_branch_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "target_branch_name", value)


class ProjectTargetBranchRule(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 project: Optional[pulumi.Input[str]] = None,
                 source_branch_pattern: Optional[pulumi.Input[str]] = None,
                 target_branch_name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        The `ProjectTargetBranchRule` resource allows to configure default target branch rules when creating a merge request.

        **Upstream API**: [GitLab GraphQL API docs](https://docs.gitlab.com/ee/api/graphql/reference/#mutationprojecttargetbranchrulecreate)

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] project: The ID or URL-encoded path of the project.
        :param pulumi.Input[str] source_branch_pattern: A pattern matching the branch name for which the merge request should have a default target branch configured.
        :param pulumi.Input[str] target_branch_name: The name of the branch to which the merge request should be addressed.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ProjectTargetBranchRuleArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        The `ProjectTargetBranchRule` resource allows to configure default target branch rules when creating a merge request.

        **Upstream API**: [GitLab GraphQL API docs](https://docs.gitlab.com/ee/api/graphql/reference/#mutationprojecttargetbranchrulecreate)

        :param str resource_name: The name of the resource.
        :param ProjectTargetBranchRuleArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ProjectTargetBranchRuleArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 project: Optional[pulumi.Input[str]] = None,
                 source_branch_pattern: Optional[pulumi.Input[str]] = None,
                 target_branch_name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ProjectTargetBranchRuleArgs.__new__(ProjectTargetBranchRuleArgs)

            if project is None and not opts.urn:
                raise TypeError("Missing required property 'project'")
            __props__.__dict__["project"] = project
            if source_branch_pattern is None and not opts.urn:
                raise TypeError("Missing required property 'source_branch_pattern'")
            __props__.__dict__["source_branch_pattern"] = source_branch_pattern
            if target_branch_name is None and not opts.urn:
                raise TypeError("Missing required property 'target_branch_name'")
            __props__.__dict__["target_branch_name"] = target_branch_name
        super(ProjectTargetBranchRule, __self__).__init__(
            'gitlab:index/projectTargetBranchRule:ProjectTargetBranchRule',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            project: Optional[pulumi.Input[str]] = None,
            source_branch_pattern: Optional[pulumi.Input[str]] = None,
            target_branch_name: Optional[pulumi.Input[str]] = None) -> 'ProjectTargetBranchRule':
        """
        Get an existing ProjectTargetBranchRule resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] project: The ID or URL-encoded path of the project.
        :param pulumi.Input[str] source_branch_pattern: A pattern matching the branch name for which the merge request should have a default target branch configured.
        :param pulumi.Input[str] target_branch_name: The name of the branch to which the merge request should be addressed.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ProjectTargetBranchRuleState.__new__(_ProjectTargetBranchRuleState)

        __props__.__dict__["project"] = project
        __props__.__dict__["source_branch_pattern"] = source_branch_pattern
        __props__.__dict__["target_branch_name"] = target_branch_name
        return ProjectTargetBranchRule(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def project(self) -> pulumi.Output[str]:
        """
        The ID or URL-encoded path of the project.
        """
        return pulumi.get(self, "project")

    @property
    @pulumi.getter(name="sourceBranchPattern")
    def source_branch_pattern(self) -> pulumi.Output[str]:
        """
        A pattern matching the branch name for which the merge request should have a default target branch configured.
        """
        return pulumi.get(self, "source_branch_pattern")

    @property
    @pulumi.getter(name="targetBranchName")
    def target_branch_name(self) -> pulumi.Output[str]:
        """
        The name of the branch to which the merge request should be addressed.
        """
        return pulumi.get(self, "target_branch_name")

